@@ -1,3 +1,17 @@
+# Copyright 2018 The Nuclio Authors.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 import typing
 from os import environ
 
@@ -113,6 +127,22 @@ class CronTrigger(NuclioTrigger):
     def __init__(
         self, interval="", schedule="", body="", headers=None, extra_attributes=None
     ):
+        """Attach cron trigger to nuclio function
+        :param interval:    e.g. '1h', '30m', '10s'
+        :param schedule:    Regular cron string as per https://pypi.org/project/croniter/
+        :param body:        Set project and workflow nuclio event body
+        :param headers:     Set nuclio event headers
+
+        Examples::
+        fn = mlrun.new_function('fn_name', kind='nuclio', image='mlrun/mlrun')
+        fn.add_trigger(
+            'trigger_name',
+            CronTrigger(
+                schedule='* * 1 * *',
+                body=json.dumps({'project_url': '~/project.yaml', 'workflow': 'main'}),
+                headers={'X-Nuclio-Target': 'fn_name'}
+        ))
+        """
         super(CronTrigger, self).__init__(
             {"kind": self.kind, "attributes": {}}
         )
@@ -161,11 +191,11 @@ class KafkaTrigger(NuclioTrigger):
         )
         partitions = partitions or []
         if partitions:
-            self._struct["attributes"]["Partitions"] = partitions
+            self._struct["attributes"]["partitions"] = partitions
         self._add_extra_attrs(extra_attributes)
 
     def sasl(self, user="", password=""):
-        self._struct["attributes"]["Sasl"] = {
+        self._struct["attributes"]["sasl"] = {
             "enable": True,
             "user": user,
             "password": password,
